==> mysql-workbench-gpl-5.2.30-src.tar.gz: mysql-workbench-gpl-5.2.30-src/backend/wbprivate/sqlide/db_sql_editor_history_be.h <==
#ifndef _DB_SQL_EDITOR_HISTORY_BE_H_
#define _DB_SQL_EDITOR_HISTORY_BE_H_


#include "workbench/wb_backend_public_interface.h"
#include "sqlide/var_grid_model_be.h"
#include <boost/shared_ptr.hpp>
#include <time.h>


class MYSQLWBBACKEND_PUBLIC_FUNC DbSqlEditorHistory
{
public:
  typedef boost::shared_ptr<DbSqlEditorHistory> Ref;
  static Ref create(bec::GRTManager *grtm) { return Ref(new DbSqlEditorHistory(grtm)); }
  virtual ~DbSqlEditorHistory();
protected:
  DbSqlEditorHistory(bec::GRTManager *grtm);
  bec::GRTManager *_grtm;

public:
  void reset();
  void add_entry(const std::list<std::string> &statements);
  int current_entry() { return _current_entry_index; }
  void current_entry(int index);
  std::string restore_sql_from_history(int entry_index, std::list<int> &detail_indexes);
protected:
  void insert_entry(const std::tm &t);
protected:
  int _current_entry_index;

public:
  void save();
  void load();

public:
  class EntriesModel;
  class DetailsModel;

public:
  class DetailsModel : public VarGridModel
  {
  public:
    typedef boost::shared_ptr<DetailsModel> Ref;
    static Ref create(bec::GRTManager *grtm) { return Ref(new DetailsModel(grtm)); }
  protected:
    DetailsModel(bec::GRTManager *grtm) : VarGridModel(grtm) { reset(); }

  public:
    virtual void refresh() { refresh_ui(); }

  public:
    virtual void reset();
    void add_entries(const std::list<std::string> &statements, bool loading_from_storage_file);
    void load_from(Ref details_model);

  public:
    std::string storage_file_path() const;
    void save();
    void load();
    bool loaded() const { return _loaded; }
  protected:
    int _last_loaded_row; // required to skip duplication of existing entries when dumping contents
    bool _loaded; // whether contents was loaded from storage file

  public:
    std::tm datestamp() const { return _datestamp; }
    void datestamp(const std::tm &val) { _datestamp= val; }
  protected:
    std::tm _datestamp; // raw datestamp for locale independent storage file name
  };

public:
  class EntriesModel : public VarGridModel
  {
  public:
    typedef boost::shared_ptr<EntriesModel> Ref;
    static Ref create(bec::GRTManager *grtm) { return Ref(new EntriesModel(grtm)); }
  protected:
    EntriesModel(bec::GRTManager *grtm) : VarGridModel(grtm) { reset(); }

  public:
    virtual void reset();
    void add_entry(const std::list<std::string> &statements);
    void insert_entry(const std::tm &t);
    void delete_entries(const std::vector<int> &rows);
    void delete_all_entries();
  public:
    DetailsModel::Ref details_model(int index) { return _details_models.at(index); }
    sigc::slot<void> reset_current_entry_index;
  protected:
    std::vector<DetailsModel::Ref> _details_models;

  public:
    void save();
    void load();

  public:
    virtual bool activate_popup_item_for_nodes(const std::string &action, const std::vector<bec::NodeId> &orig_nodes);
    virtual bec::MenuItemList get_popup_items_for_nodes(const std::vector<bec::NodeId> &nodes);
  };

public:
  EntriesModel::Ref entries_model() { return _entries_model; }
  DetailsModel::Ref details_model() { return _details_model; }
protected:
  EntriesModel::Ref _entries_model;
  DetailsModel::Ref _details_model;
};


#endif /* _DB_SQL_EDITOR_HISTORY_BE_H_ */

==> mysql-workbench-gpl-5.2.34-src.tar.gz: mysql-workbench-gpl-5.2.34-src/backend/wbprivate/sqlide/db_sql_editor_history_be.h <==
#ifndef _DB_SQL_EDITOR_HISTORY_BE_H_
#define _DB_SQL_EDITOR_HISTORY_BE_H_


#include "workbench/wb_backend_public_interface.h"
#include "sqlide/var_grid_model_be.h"
#include <boost/shared_ptr.hpp>
#include <time.h>


class MYSQLWBBACKEND_PUBLIC_FUNC DbSqlEditorHistory
{
public:
  typedef boost::shared_ptr<DbSqlEditorHistory> Ref;
  static Ref create(bec::GRTManager *grtm) { return Ref(new DbSqlEditorHistory(grtm)); }
  virtual ~DbSqlEditorHistory();
protected:
  DbSqlEditorHistory(bec::GRTManager *grtm);
  bec::GRTManager *_grtm;

public:
  void reset();
  void add_entry(const std::list<std::string> &statements);
  int current_entry() { return _current_entry_index; }
  void current_entry(int index);
  std::string restore_sql_from_history(int entry_index, std::list<int> &detail_indexes);
protected:
  void insert_entry(const std::tm &t);
protected:
  int _current_entry_index;

public:
  void save();
  void load();

public:
  class EntriesModel;
  class DetailsModel;

public:
  class DetailsModel : public VarGridModel
  {
  public:
    typedef boost::shared_ptr<DetailsModel> Ref;
    static Ref create(bec::GRTManager *grtm) { return Ref(new DetailsModel(grtm)); }
  protected:
    DetailsModel(bec::GRTManager *grtm) : VarGridModel(grtm) { reset(); }

  public:
    virtual void refresh() { refresh_ui(); }

  public:
    virtual void reset();
    void add_entries(const std::list<std::string> &statements);
    void load_from(Ref details_model);

  public:
    std::string storage_file_path() const;
    void save();
    void load();
    bool loaded() const { return _loaded; }
  protected:
    int _last_loaded_row; // required to skip duplication of existing entries when dumping contents
    bool _loaded; // whether contents was loaded from storage file

  public:
    std::tm datestamp() const { return _datestamp; }
    void datestamp(const std::tm &val) { _datestamp= val; }
  protected:
    std::tm _datestamp; // raw datestamp for locale independent storage file name

  private:
    grt::StringRef _last_timestamp;
    grt::StringRef _last_statement;
  };

public:
  class EntriesModel : public VarGridModel
  {
  public:
    typedef boost::shared_ptr<EntriesModel> Ref;
    static Ref create(bec::GRTManager *grtm) { return Ref(new EntriesModel(grtm)); }
  protected:
    EntriesModel(bec::GRTManager *grtm) : VarGridModel(grtm) { reset(); }

  public:
    virtual void reset();
    void add_entry(const std::list<std::string> &statements);
    void insert_entry(const std::tm &t);
    void delete_entries(const std::vector<int> &rows);
    void delete_all_entries();
  public:
    DetailsModel::Ref details_model(int index) { return _details_models.at(index); }
    sigc::slot<void> reset_current_entry_index;
  protected:
    std::vector<DetailsModel::Ref> _details_models;

  public:
    void save();
    void load();

  public:
    virtual bool activate_popup_item_for_nodes(const std::string &action, const std::vector<bec::NodeId> &orig_nodes);
    virtual bec::MenuItemList get_popup_items_for_nodes(const std::vector<bec::NodeId> &nodes);
  };

public:
  EntriesModel::Ref entries_model() { return _entries_model; }
  DetailsModel::Ref details_model() { return _details_model; }
protected:
  EntriesModel::Ref _entries_model;
  DetailsModel::Ref _details_model;
};


#endif /* _DB_SQL_EDITOR_HISTORY_BE_H_ */
